@@ -260,8 +260,17 @@ sub ACTION_create_apps {
     mkpath "_build/apps" unless -d "_build/apps";
 
     my $libs = $self->notes('libs');
+
+    if ($self->notes('lddlflags_had_local_lib')
+        ||
+        $self->notes('ldflags_had_local_lib'))
+    {
+       $libs = " -L/usr/local/lib $libs";
+    }
+
     $libs = "-L_build/lib -lnatools $libs";
 
+
     my $libbuilder = $self->notes('libbuilder');
     my $EXE = $libbuilder->{exeext};
     for my $app (keys %app_deps) {
@@ -300,6 +309,15 @@ sub ACTION_create_library {
     if (!$self->up_to_date(\@objects, $libfile)) {
         _LOG_ "  [ld] building libnatools$LIBEXT";
 
+
+        if ($self->notes('lddlflags_had_local_lib')
+            ||
+            $self->notes('ldflags_had_local_lib'))
+        {
+          $extralinkerflags = "-L/usr/local/lib $extralinkerflags";
+        }
+
+
         my ($stdout, $stderr, $result) = capture {
             eval {
                 $libbuilder->link(module_name => 'libnatools',
@@ -338,8 +356,17 @@ sub ACTION_create_test_binaries {
     $cflags .= " -DMISSES_WCSDUP" unless $self->notes('have_wcsdup');
     $cflags .= " -g -Wall -Werror" if $pedantic;
 
+    my $ldlibs = "";
+    if ($self->notes('lddlflags_had_local_lib')
+        ||
+        $self->notes('ldflags_had_local_lib'))
+    {
+       $ldlibs = " -L/usr/local/lib ";
+    }
+
     my $libs = join(" ",
                     "-L_build/lib -lnatools",
+                    $ldlibs,
                     $self->notes('libs'));
     my $EXE = $libbuilder->{exeext};
     for my $test (keys %tests) {
@@ -394,15 +421,22 @@ sub ACTION_test {
 
 sub _set_libbuilder {
     my $self = shift;
-    my ($out, $err, $libbuilder) = capture { ExtUtils::LibBuilder->new(); };
+    my ($out, $err, $libbuilder) = capture {ExtUtils::LibBuilder->new(); };
 
     ## Mac OS X hack
     $libbuilder->{config}{ccflags} =~ s/-arch \S+//g;
     $libbuilder->{config}{lddlflags} =~ s/-arch \S+//g;
     $libbuilder->{config}{ldflags} =~ s/-arch \S+//g;
 
-    $libbuilder->{config}{lddlflags} =~ s{ -L\s*/usr/local/lib(?:$|\b)}{};
-    $libbuilder->{config}{ldflags} =~ s{ -L\s*/usr/local/lib(?:$|\b)}{};
+    if ($libbuilder->{config}{lddlflags} =~ 
+        s{ -L\s*/usr/local/lib(?:$|\b)}{}) {
+      $self->notes(lddlflags_had_local_lib => 1);
+    }
+
+    if ($libbuilder->{config}{ldflags} =~
+        s{ -L\s*/usr/local/lib(?:$|\b)}{}) {
+      $self->notes(ldflags_had_local_lib => 1);
+    } 
 
     $self->notes(libbuilder => $libbuilder);
 }
@@ -456,6 +490,14 @@ sub ACTION_compile_xscode {
     if ( !$self->up_to_date( $objects, $lib_file ) ) {
         my $libdir = $self->install_path('usrlib');
         my $libs = $self->notes('libs');
+
+        if ($self->notes('lddlflags_had_local_lib')
+            ||
+            $self->notes('ldflags_had_local_lib'))
+        {
+           $libs = " -L/usr/local/lib $libs";
+        }
+
         $libs = "-L_build/lib -lnatools $libs";
 
         _LOG_ "  [LD] NATools.$Config{dlext}";
@@ -608,14 +650,21 @@ EOP
 
     $CAC->msg_checking("for Berkeley DB header >= $minvermajor.$minverminor.$minverpatch");
     $CAC->compile_if_else($app,
-                          sub { $CAC->msg_result("yes"); },
-                          sub { $CAC->msg_result("no"); $builder->FAIL });
+                          {
+                            action_on_true => sub {
+                               $CAC->msg_result("yes");
+                            },
+                            action_on_false => sub {
+                              $CAC->msg_result("no");
+                              $builder->FAIL
+                            }} );
 
     $CAC->msg_checking("for Berkeley DB library >= $minvermajor.$minverminor.$minverpatch");
     $CAC->push_libraries("db");
     $CAC->link_if_else($app,
-                       sub { $CAC->msg_result("yes"); },
-                       sub { $CAC->msg_result("no"); $builder->FAIL });
+                       {
+                        action_on_true => sub { $CAC->msg_result("yes"); },
+                        action_on_false => sub { $CAC->msg_result("no"); $builder->FAIL }});
 
     $builder->notes('libs' => $builder->notes('libs') . " -ldb");
 }
